pub struct FrontendApp {Show 31 fields
pub id: String,
pub name: String,
pub app_type: AppType,
pub runner: Runner,
pub deployment_method: DeploymentMethod,
pub project_id: i32,
pub tenant_id: i32,
pub repository: Option<String>,
pub description: Option<String>,
pub deploy_repo_id: Option<i64>,
pub source_path: Option<String>,
pub deploy_repo: Option<DeployRepo>,
pub project_ids: Vec<i32>,
pub kind: Option<String>,
pub source: Option<String>,
pub output: Option<String>,
pub package_manager: Option<String>,
pub pm2_app: Option<String>,
pub shared_lib: Option<String>,
pub compile_cmd: Option<String>,
pub path: Option<String>,
pub remote_path: Option<String>,
pub output_path: Option<String>,
pub build_command: Option<String>,
pub install_command: Option<String>,
pub binary_name: Option<String>,
pub build_target: Option<String>,
pub port: Option<u16>,
pub shared_lib_path: Option<String>,
pub created_at: DateTime<Utc>,
pub updated_at: DateTime<Utc>,
}Fields
id: Stringname: Stringapp_type: AppTyperunner: Runnerdeployment_method: DeploymentMethodproject_id: i32tenant_id: i32repository: Option<String>description: Option<String>deploy_repo_id: Option<i64>source_path: Option<String>deploy_repo: Option<DeployRepo>project_ids: Vec<i32>kind: Option<String>Deployment kind, e.g. “vite-spa”. Absent for server-side runners.
source: Option<String>Local source directory to build from, e.g. “frontend/my-app”.
output: Option<String>Build output directory relative to source, e.g. “dist”.
package_manager: Option<String>Package manager to use for the build step, e.g. “pnpm”.
pm2_app: Option<String>PM2 process name to restart after a nextjs-ssr deploy.
Path to a shared lib directory to rsync before deploying.
compile_cmd: Option<String>SSH command to run on the server after rsyncing the shared lib.
path: Option<String>Remote destination path on the server.
remote_path: Option<String>output_path: Option<String>build_command: Option<String>install_command: Option<String>binary_name: Option<String>build_target: Option<String>port: Option<u16>created_at: DateTime<Utc>updated_at: DateTime<Utc>Trait Implementations
Sourceimpl Clone for FrontendApp
impl Clone for FrontendApp
Sourcefn clone(&self) -> FrontendApp
fn clone(&self) -> FrontendApp
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for FrontendApp
impl Debug for FrontendApp
Sourceimpl<'de> Deserialize<'de> for FrontendApp
impl<'de> Deserialize<'de> for FrontendApp
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl Display for FrontendApp
impl Display for FrontendApp